# kddl
Infrastructure for training neural networks in Pytorch. Intended for personal projects.

# Installation

This project depends on [PyTorch](https://pytorch.org/), which should be installed first. 

```bash
pip install kddl
```
